@@ -1,7 +1,7 @@
 /*
- *  Copyright (C) 2002 Jorn Baayen <jorn@nl.linux.org>
- *  Copyright (C) 2003-2004 Marco Pesenti Gritti
- *  Copyright (C) 2004, 2005 Christian Persch
+ *  Copyright © 2002 Jorn Baayen <jorn@nl.linux.org>
+ *  Copyright © 2003-2004 Marco Pesenti Gritti
+ *  Copyright © 2004, 2005 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-favicon-cache.c,v 1.57 2006/05/10 18:06:59 chpe Exp $
+ *  $Id: ephy-favicon-cache.c,v 1.58.2.2 2006/09/13 11:48:29 chpe Exp $
  */
 
 #include "config.h"
@@ -125,7 +125,7 @@ ephy_favicon_cache_get_type (void)
 
 	if (G_UNLIKELY (type == 0))
 	{
-		static const GTypeInfo our_info =
+		const GTypeInfo our_info =
 		{
 			sizeof (EphyFaviconCacheClass),
 			NULL,
@@ -553,7 +553,9 @@ ephy_favicon_cache_download (EphyFaviconCache *cache,
 	ephy_embed_persist_set_dest (persist, dest);
 	ephy_embed_persist_set_flags (persist, EPHY_EMBED_PERSIST_NO_VIEW |
 					       EPHY_EMBED_PERSIST_NO_CERTDIALOGS |
-					       EPHY_EMBED_PERSIST_DO_CONVERSION);
+					       EPHY_EMBED_PERSIST_DO_CONVERSION |
+					       EPHY_EMBED_PERSIST_NO_COOKIES
+				               );
 	ephy_embed_persist_set_max_size (persist, EPHY_FAVICON_MAX_SIZE);
 	ephy_embed_persist_set_source (persist, favicon_url);
 
