@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2000-2004 Marco Pesenti Gritti
+ *  Copyright © 2000-2004 Marco Pesenti Gritti
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,30 +15,28 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EphyBrowser.h,v 1.49 2005/10/13 03:14:12 philipl Exp $
+ *  $Id: EphyBrowser.h,v 1.53.2.2 2006/11/05 20:15:24 jframeau Exp $
  */
 
 #ifndef EPHY_BROWSER_H
 #define EPHY_BROWSER_H
 
-#include "config.h"
-
 #include "ephy-embed.h"
 #include <gtk/gtkwidget.h>
 
 #include <gtkmozembed.h>
 #include <nsCOMPtr.h>
-#include <nsIDOMEventListener.h>
 #include <nsIDOMContextMenuListener.h>
-#include <nsIDOMEventTarget.h>
-#include <nsIWebNavigation.h>
-#include <nsISHistory.h>
-#include <nsIWebBrowser.h>
-#include <nsIWebBrowserFocus.h>
 #include <nsIDOMDocument.h>
+#include <nsIDOMEventListener.h>
+#include <nsIDOMEventTarget.h>
 #include <nsIDOMWindow.h>
-#include <nsIPrintSettings.h>
 #include <nsIRequest.h>
+#include <nsISHistory.h>
+#include <nsIWebBrowserFocus.h>
+#include <nsIWebBrowser.h>
+#include <nsIWebNavigation.h>
+#include <nsPIDOMWindow.h>
 
 #ifdef ALLOW_PRIVATE_API
 #include <nsIContentViewer.h>
@@ -147,6 +145,10 @@ public:
 	nsresult SetZoom (float aTextZoom);
 	nsresult GetZoom (float *aTextZoom);
 
+	nsresult ScrollLines (PRInt32 aNumLines);
+	nsresult ScrollPages (PRInt32 aNumPages);
+	nsresult ScrollPixels (PRInt32 aDeltaX, PRInt32 aDeltaY);
+
 	nsresult Print ();
 	nsresult SetPrintPreviewMode (PRBool previewMode);
 	nsresult PrintPreviewNumPages (int *numPages);
@@ -171,6 +173,7 @@ public:
 	nsresult GetDocumentURI (nsIURI **aURI);
 	nsresult GetTargetDocumentURI (nsIURI **aURI);
 	nsresult GetDOMWindow (nsIDOMWindow **window);
+	nsresult GetPIDOMWindow(nsPIDOMWindow **aPIWin);
 
 	nsresult GetHasModifiedForms (PRBool *modified);
 
@@ -182,12 +185,11 @@ public:
 
 	nsresult Close ();
 
-        EphyEmbedDocumentType GetDocumentType ();
+	nsresult LoadURI(const char *aURI, 
+			 PRUint32 aLoadFlags = nsIWebNavigation::LOAD_FLAGS_NONE, 
+			 nsIURI *aURI = nsnull);
 
-#ifndef HAVE_GECKO_1_8
-	nsresult FocusActivate ();
-	nsresult FocusDeactivate ();
-#endif /* !HAVE_GECKO_1_8 */
+        EphyEmbedDocumentType GetDocumentType ();
 
 	nsCOMPtr<nsIWebBrowser> mWebBrowser;
 private:
