@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2006 Christian Persch
+ *  Copyright © 2006 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-spell-check.c,v 1.2 2006/07/24 21:36:03 jframeau Exp $
+ *  $Id: ephy-spell-check.c,v 1.2.2.3 2006/11/03 19:11:59 chpe Exp $
  */
 
 #include "config.h"
@@ -124,7 +124,7 @@ ephy_spell_check_get_type (void)
 
 	if (G_UNLIKELY (type == 0))
 	{
-		static const GTypeInfo our_info =
+		const GTypeInfo our_info =
 		{
 			sizeof (EphySpellCheckClass),
 			NULL,
@@ -182,8 +182,6 @@ ephy_spell_check_check_word (EphySpellCheck *speller,
 
 	g_return_val_if_fail (word != NULL, -1);
 
-	g_print ("ephy_spell_check_check_word: '%s'\n", word);
-
 	if (priv->dict == NULL)
 		return FALSE;
 
