@@ -1,6 +1,6 @@
 /*
- *  Copyright (C) 2002-2004 Marco Pesenti Gritti
- *  Copyright (C) 2003, 2004 Christian Persch
+ *  Copyright © 2002-2004 Marco Pesenti Gritti
+ *  Copyright © 2003, 2004 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-bookmarks.c,v 1.130 2006/05/14 19:39:12 chpe Exp $
+ *  $Id: ephy-bookmarks.c,v 1.131.2.3 2006/10/15 12:50:18 jframeau Exp $
  */
 
 #include "config.h"
@@ -136,7 +136,7 @@ ephy_bookmarks_get_type (void)
 
 	if (G_UNLIKELY (type == 0))
 	{
-		static const GTypeInfo our_info =
+		const GTypeInfo our_info =
 		{
 			sizeof (EphyBookmarksClass),
 			NULL, /* base_init */
@@ -842,16 +842,6 @@ resolve_cb (GnomeVFSDNSSDResolveHandle *handle,
 	gboolean was_immutable;
 	guint i;
 
-	/* Find the protocol */
-	for (i = 0; i < G_N_ELEMENTS (zeroconf_protos); ++i)
-	{
-		char proto[20];
-
-		g_snprintf (proto, sizeof (proto), "_%s._tcp", zeroconf_protos[i]);
-		if (strcmp (service->type, proto) == 0) break;
-	}
-	if (i == G_N_ELEMENTS (zeroconf_protos)) return;
-
 	was_immutable = ephy_node_db_is_immutable (priv->db);
 	ephy_node_db_set_immutable (priv->db, FALSE);
 
@@ -867,6 +857,16 @@ resolve_cb (GnomeVFSDNSSDResolveHandle *handle,
 		return;
 	}
 
+	/* Find the protocol */
+	for (i = 0; i < G_N_ELEMENTS (zeroconf_protos); ++i)
+	{
+		char proto[20];
+
+		g_snprintf (proto, sizeof (proto), "_%s._tcp", zeroconf_protos[i]);
+		if (strcmp (service->type, proto) == 0) break;
+	}
+	if (i == G_N_ELEMENTS (zeroconf_protos)) return;
+
 	if (text != NULL)
 	{
 		path = g_hash_table_lookup (text, "path");
@@ -1272,7 +1272,10 @@ update_has_smart_address (EphyBookmarks *bookmarks, EphyNode *bmk, const char *a
 	 */
 	if (smart && with_options)
 	{
-		ephy_node_remove_child (smart_bmks, bmk);
+		if (ephy_node_has_child (smart_bmks, bmk))
+		{
+			ephy_node_remove_child (smart_bmks, bmk);
+		}
 		ephy_node_add_child (smart_bmks, bmk);
 	}
 	else if (smart)
