@@ -1,6 +1,6 @@
 /*
- *  Copyright (C) 2004 Tommi Komulainen
- *  Copyright (C) 2004, 2005 Christian Persch
+ *  Copyright © 2004 Tommi Komulainen
+ *  Copyright © 2004, 2005 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: ephy-find-toolbar.c,v 1.30 2006/05/11 14:24:48 wbolster Exp $
+ *  $Id: ephy-find-toolbar.c,v 1.30.2.2 2006/09/13 11:48:50 chpe Exp $
  */
 
 #include "config.h"
@@ -517,7 +517,7 @@ ephy_find_toolbar_get_type (void)
 
 	if (G_UNLIKELY (type == 0))
 	{
-		static const GTypeInfo our_info =
+		const GTypeInfo our_info =
 		{
 			sizeof (EphyFindToolbarClass),
 			NULL, /* base_init */
