@@ -1,6 +1,6 @@
 /*
- *  Copyright (C) 2003, 2004 Marco Pesenti Gritti
- *  Copyright (C) 2003, 2004 Christian Persch
+ *  Copyright © 2003, 2004 Marco Pesenti Gritti
+ *  Copyright © 2003, 2004 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-location-action.c,v 1.45 2006/07/10 19:23:45 chpe Exp $
+ *  $Id: ephy-location-action.c,v 1.45.2.3 2006/11/05 20:15:24 jframeau Exp $
  */
 
 #include "config.h"
@@ -91,7 +91,7 @@ ephy_location_action_get_type (void)
 
 	if (G_UNLIKELY (type == 0))
 	{
-		static const GTypeInfo type_info =
+		const GTypeInfo type_info =
 		{
 			sizeof (EphyLocationActionClass),
 			(GBaseInitFunc) NULL,
@@ -139,7 +139,7 @@ action_activated_cb (GtkEntryCompletion *completion,
 		if (url == NULL) return;
 
  		ephy_link_open (EPHY_LINK (action), url, NULL,
-			        ephy_link_flags_from_current_event ());
+			        ephy_link_flags_from_current_event () | EPHY_LINK_ALLOW_FIXUP);
 
 		g_free (url);
 	}
@@ -162,7 +162,7 @@ entry_activate_cb (GtkEntry *entry,
 	g_return_if_fail (address != NULL);
 
 	ephy_link_open (EPHY_LINK (action), address, NULL, 
-		        ephy_link_flags_from_current_event ());
+		        ephy_link_flags_from_current_event () | EPHY_LINK_ALLOW_FIXUP);
 
 	g_free (address);
 }
