@@ -1,7 +1,7 @@
 /*
- *  Copyright (C) 2002 Christophe Fergeau
- *  Copyright (C) 2003 Marco Pesenti Gritti
- *  Copyright (C) 2003, 2004 Christian Persch
+ *  Copyright © 2002 Christophe Fergeau
+ *  Copyright © 2003 Marco Pesenti Gritti
+ *  Copyright © 2003, 2004 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-notebook.h,v 1.13 2005/04/17 19:38:59 chpe Exp $
+ *  $Id: ephy-notebook.h,v 1.16.2.1 2006/09/13 11:48:52 chpe Exp $
  */
 
 #ifndef EPHY_NOTEBOOK_H
@@ -54,40 +54,25 @@ struct _EphyNotebookClass
         GtkNotebookClass parent_class;
 
 	/* Signals */
-	void	 (* tab_added)      (EphyNotebook *notebook,
-				     EphyTab *tab);
-	void	 (* tab_removed)    (EphyNotebook *notebook,
-				     EphyTab *tab);
-	void	 (* tab_detached)   (EphyNotebook *notebook,
-				     EphyTab *tab);
-	void	 (* tabs_reordered) (EphyNotebook *notebook);
-	gboolean (* tab_delete)	    (EphyNotebook *notebook,
+	void	 (* tab_close_req)  (EphyNotebook *notebook,
 				     EphyTab *tab);
 };
 
 GType		ephy_notebook_get_type		(void);
 
-GtkWidget      *ephy_notebook_new		(void);
-
-void		ephy_notebook_add_tab		(EphyNotebook *nb,
+int		ephy_notebook_add_tab		(EphyNotebook *nb,
 						 EphyTab *tab,
 						 int position,
 						 gboolean jump_to);
-
-void		ephy_notebook_remove_tab	(EphyNotebook *nb,
-						 EphyTab *tab);
-
-void            ephy_notebook_move_tab		(EphyNotebook *src,
-						 EphyNotebook *dest,
-						 EphyTab *tab,
-						 int dest_position);
-
+	
 void		ephy_notebook_set_show_tabs	(EphyNotebook *nb,
 						 gboolean show_tabs);
 
 void		ephy_notebook_set_dnd_enabled	(EphyNotebook *nb,
 						 gboolean enabled);
 
+GList *         ephy_notebook_get_focused_pages (EphyNotebook *nb);
+
 G_END_DECLS
 
 #endif /* EPHY_NOTEBOOK_H */
