@@ -1,6 +1,6 @@
 /*
- *  Copyright (C) 2000-2004 Marco Pesenti Gritti
- *  Copyright (C) 2003, 2004, 2006 Christian Persch
+ *  Copyright © 2000-2004 Marco Pesenti Gritti
+ *  Copyright © 2003, 2004, 2006 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,11 +16,17 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-shell.c,v 1.140 2006/02/04 10:47:27 paharvey Exp $
+ *  $Id: ephy-shell.c,v 1.144.2.4 2006/11/19 13:36:55 jframeau Exp $
  */
 
 #include "config.h"
 
+#include <string.h>
+#include <glib/gi18n.h>
+#include <gtk/gtknotebook.h>
+#include <dirent.h>
+#include <unistd.h>
+
 #include "ephy-shell.h"
 #include "ephy-type-builtins.h"
 #include "ephy-embed-shell.h"
@@ -44,16 +50,9 @@
 #include "egg-toolbars-model.h"
 #include "ephy-toolbars-model.h"
 #include "ephy-toolbar.h"
-#include "print-dialog.h"
 #include "ephy-prefs.h"
 #include "ephy-gui.h"
 
-#include <string.h>
-#include <glib/gi18n.h>
-#include <gtk/gtknotebook.h>
-#include <dirent.h>
-#include <unistd.h>
-
 #ifdef ENABLE_NETWORK_MANAGER
 #include "ephy-net-monitor.h"
 #endif
@@ -75,7 +74,6 @@ struct _EphyShellPrivate
 	GtkWidget *history_window;
 	GObject *pdm_dialog;
 	GObject *prefs_dialog;
-	GObject *print_setup_dialog;
 	GList *del_on_exit;
 
 	guint embed_single_connected : 1;
@@ -98,7 +96,7 @@ ephy_shell_get_type (void)
 
 	if (G_UNLIKELY (type == 0))
 	{
-		static const GTypeInfo our_info =
+		const GTypeInfo our_info =
 		{
 			sizeof (EphyShellClass),
 			NULL, /* base_init */
@@ -354,13 +352,6 @@ ephy_shell_dispose (GObject *object)
 		priv->prefs_dialog = NULL;
 	}
 
-	if (priv->print_setup_dialog != NULL)
-	{
-		LOG ("Unref print setup dialog");
-		g_object_unref (priv->print_setup_dialog);
-		priv->print_setup_dialog = NULL;
-	}
-
 	if (priv->bookmarks != NULL)
 	{
 		LOG ("Unref bookmarks");
@@ -517,6 +508,15 @@ ephy_shell_new_tab_full (EphyShell *shell,
 
 	ephy_window_add_tab (window, tab, position, jump_to);
 
+	if (previous_embed != NULL)
+	{
+		ephy_embed_shistory_copy (previous_embed,
+					  embed,
+					  TRUE,   /* back history */
+					  TRUE,   /* forward history */
+					  FALSE); /* current index */
+	}
+
 	ephy_gui_window_update_user_time (GTK_WIDGET (window), user_time);
 
 	if ((flags & EPHY_NEW_TAB_DONT_SHOW_WINDOW) == 0)
@@ -539,8 +539,20 @@ ephy_shell_new_tab_full (EphyShell *shell,
 	}
 	else if (flags & EPHY_NEW_TAB_OPEN_PAGE)
 	{
+		EphyEmbedLoadFlags load_flags = 0;
+
 		g_assert (url != NULL);
-		ephy_embed_load_url (embed, url);
+
+		if (flags & EPHY_NEW_TAB_ALLOW_FIXUP)
+		{
+			load_flags = EPHY_EMBED_LOAD_FLAGS_ALLOW_THIRD_PARTY_FIXUP;
+		}
+		else
+		{
+			load_flags = EPHY_EMBED_LOAD_FLAGS_NONE;
+		}
+		ephy_embed_load (embed, url, load_flags, previous_embed);
+
 		is_empty = url_is_empty (url);
 	}
 
@@ -668,6 +680,7 @@ ephy_shell_get_toolbars_model (EphyShell *shell, gboolean fullscreen)
 	{
 		if (shell->priv->fs_toolbars_model == NULL)
 		{
+			EggTbModelFlags flags;
 			gboolean success;
 			const char *xml;
 
@@ -678,6 +691,12 @@ ephy_shell_get_toolbars_model (EphyShell *shell, gboolean fullscreen)
 			success = egg_toolbars_model_load_toolbars
 				(shell->priv->fs_toolbars_model, xml);
 			g_return_val_if_fail (success, NULL);
+
+			flags = egg_toolbars_model_get_flags 
+			  (shell->priv->fs_toolbars_model, 0);
+			egg_toolbars_model_set_flags
+			  (shell->priv->fs_toolbars_model, 0, 
+			   flags | EGG_TB_MODEL_NOT_REMOVABLE);
 		}
 
 		return G_OBJECT (shell->priv->fs_toolbars_model);
@@ -808,10 +827,14 @@ ephy_shell_get_pdm_dialog (EphyShell *shell)
 {
 	if (shell->priv->pdm_dialog == NULL)
 	{
+		GObject **dialog;
+
 		shell->priv->pdm_dialog = g_object_new (EPHY_TYPE_PDM_DIALOG, NULL);
 
+		dialog = &shell->priv->pdm_dialog;
+
 		g_object_add_weak_pointer (shell->priv->pdm_dialog,
-					   (gpointer *) &shell->priv->pdm_dialog);
+					   (gpointer *) dialog);
 	}
 
 	return shell->priv->pdm_dialog;
@@ -822,29 +845,19 @@ ephy_shell_get_prefs_dialog (EphyShell *shell)
 {
 	if (shell->priv->prefs_dialog == NULL)
 	{
+		GObject **dialog;
+
 		shell->priv->prefs_dialog = g_object_new (EPHY_TYPE_PREFS_DIALOG, NULL);
 
+		dialog  = &shell->priv->prefs_dialog;
+
 		g_object_add_weak_pointer (shell->priv->prefs_dialog,
-					   (gpointer *) &shell->priv->prefs_dialog);
+					   (gpointer *) dialog);
 	}
 
 	return shell->priv->prefs_dialog;
 }
 
-GObject *
-ephy_shell_get_print_setup_dialog (EphyShell *shell)
-{
-	if (shell->priv->print_setup_dialog == NULL)
-	{
-		shell->priv->print_setup_dialog = G_OBJECT (ephy_print_setup_dialog_new ());
-
-		g_object_add_weak_pointer (shell->priv->print_setup_dialog,
-					   (gpointer *) &shell->priv->print_setup_dialog);
-	}
-
-	return shell->priv->print_setup_dialog;
-}
-
 void
 _ephy_shell_create_instance (void)
 {
