@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-shell.h,v 1.38.2.1 2006/09/13 11:48:53 chpe Exp $
+ *  $Id: ephy-shell.h,v 1.38.2.2 2006/11/05 20:15:25 jframeau Exp $
  */
 
 #ifndef EPHY_SHELL_H
@@ -62,6 +62,10 @@ typedef enum
 	EPHY_NEW_TAB_JUMP		= 1 << 9,
 	EPHY_NEW_TAB_IN_NEW_WINDOW	= 1 << 10,
 	EPHY_NEW_TAB_IN_EXISTING_WINDOW	= 1 << 11,
+
+	/* The way to load */
+	EPHY_NEW_TAB_ALLOW_FIXUP	= 1 << 12,
+	
 } EphyNewTabFlags;
 
 struct _EphyShell
