@@ -1,7 +1,7 @@
 /*
- *  Copyright (C) 2002 Jorn Baayen
- *  Copyright (C) 2003-2004 Marco Pesenti Gritti
- *  Copyright (C) 2003, 2004, 2005 Christian Persch
+ *  Copyright © 2002 Jorn Baayen
+ *  Copyright © 2003-2004 Marco Pesenti Gritti
+ *  Copyright © 2003, 2004, 2005 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-toolbar.h,v 1.5 2005/08/01 15:57:48 chpe Exp $
+ *  $Id: ephy-toolbar.h,v 1.8.4.1 2006/09/13 11:48:53 chpe Exp $
  */
 
 #ifndef EPHY_TOOLBAR_H
@@ -65,6 +65,8 @@ GType		ephy_toolbar_get_type			(void);
 
 EphyToolbar    *ephy_toolbar_new			(EphyWindow *window);
 
+GtkActionGroup *ephy_toolbar_get_action_group		(EphyToolbar *toolbar);
+
 void		ephy_toolbar_set_favicon		(EphyToolbar *toolbar,
 							 GdkPixbuf *icon);
 
@@ -85,13 +87,11 @@ void		ephy_toolbar_set_navigation_actions	(EphyToolbar *toolbar,
 							 gboolean up);
 
 void		ephy_toolbar_set_security_state		(EphyToolbar *toolbar,
+							 gboolean is_secure,
 							 gboolean show_lock,
 							 const char *stock_id,
 							 const char *tooltip);
 
-void		ephy_toolbar_set_lock_visibility	(EphyToolbar *toolbar,
-							 gboolean visible);
-
 void		ephy_toolbar_set_spinning		(EphyToolbar *toolbar,
 							 gboolean spinning);
 
